@@ -1,7 +1,11 @@
-from .util import DestructiveYubikeyTestCase
+import unittest
+
+from .framework import DestructiveYubikeyTestCase, exactly_one_yubikey_present
 from ykman import driver_fido, driver_otp, driver_ccid
 
 
+@unittest.skipIf(not exactly_one_yubikey_present(),
+                 'Exactly one YubiKey must be present.')
 class TestInterfaces(DestructiveYubikeyTestCase):
 
     def test_switch_interfaces(self):
