@@ -33,7 +33,7 @@ class TestUtilityFunctions(unittest.TestCase):
         for l in range(0, 38):
             self.assertRegex(
                 generate_static_pw(l),
-                '^[cbdefghijklnrtuvCBDEFGHIJKLNRTUV]{' + '{:d}'.format(l) + '}$')
+                '^[cbdefghijklnrtuvCBDEFGHIJKLNRTUV]{%d}$' % l)
 
     def test_hmac_shorten_key(self):
         self.assertEqual(b'short', hmac_shorten_key(b'short', 'sha1'))
@@ -68,7 +68,7 @@ class TestUtilityFunctions(unittest.TestCase):
         )
 
     def test_parse_tlvs(self):
-        tlvs = parse_tlvs(b'\x00\x02\xd0\x0d\xa1\x00\xff\x04\xfe\xed\xfa\xce')
+        tlvs = parse_tlvs(b'\x00\x02\xd0\x0d\xa1\x00\xfe\x04\xfe\xed\xfa\xce')
         self.assertEqual(3, len(tlvs))
 
         self.assertEqual(0, tlvs[0].tag)
@@ -79,7 +79,7 @@ class TestUtilityFunctions(unittest.TestCase):
         self.assertEqual(0, tlvs[1].length)
         self.assertEqual(b'', tlvs[1].value)
 
-        self.assertEqual(0xff, tlvs[2].tag)
+        self.assertEqual(0xfe, tlvs[2].tag)
         self.assertEqual(4, tlvs[2].length)
         self.assertEqual(b'\xfe\xed\xfa\xce', tlvs[2].value)
 
@@ -96,7 +96,7 @@ class TestUtilityFunctions(unittest.TestCase):
                          time_challenge(1484223461.2644958))
 
     def test_tlv(self):
-        self.assertEqual(Tlv(b'\xff\6foobar'), Tlv(0xff, b'foobar'))
+        self.assertEqual(Tlv(b'\xfe\6foobar'), Tlv(0xfe, b'foobar'))
 
         tlv1 = Tlv(b'\0\5hello')
         tlv2 = Tlv(0xff, b'')
@@ -146,15 +146,14 @@ class TestUtilityFunctions(unittest.TestCase):
         with open_file('rsa_2048_key_cert.pfx') as rsa_2048_key_cert_pfx:
             self.assertFalse(is_pem(rsa_2048_key_cert_pfx.read()))
 
-        with open_file('rsa_2048_cert_metadata.pem') as rsa_2048_cert_metadata_pem:
-            self.assertTrue(is_pem(rsa_2048_cert_metadata_pem.read()))
+        with open_file('rsa_2048_cert_metadata.pem') as f:
+            self.assertTrue(is_pem(f.read()))
 
         with open_file(
             'rsa_2048_key_cert_encrypted.pfx') as \
                 rsa_2048_key_cert_encrypted_pfx:
             self.assertFalse(is_pem(rsa_2048_key_cert_encrypted_pfx.read()))
 
-
     def test_form_factor_from_code(self):
         self.assertEqual(FORM_FACTOR.UNKNOWN, FORM_FACTOR.from_code(None))
         with self.assertRaises(ValueError):
@@ -166,4 +165,6 @@ class TestUtilityFunctions(unittest.TestCase):
         self.assertEqual(
             FORM_FACTOR.USB_C_KEYCHAIN, FORM_FACTOR.from_code(0x03))
         self.assertEqual(FORM_FACTOR.USB_C_NANO, FORM_FACTOR.from_code(0x04))
-        self.assertEqual(FORM_FACTOR.UNKNOWN, FORM_FACTOR.from_code(0x05))
+        self.assertEqual(FORM_FACTOR.USB_C_LIGHTNING,
+                         FORM_FACTOR.from_code(0x05))
+        self.assertEqual(FORM_FACTOR.UNKNOWN, FORM_FACTOR.from_code(0x06))
