@@ -28,6 +28,8 @@
 from __future__ import absolute_import, print_function
 
 import ykman.logging_setup
+import smartcard.pcsc.PCSCExceptions
+
 from ykman import __version__
 from ..util import TRANSPORT, Cve201715361VulnerableError, YUBIKEY
 from ..native.pyusb import get_usb_backend_version
@@ -96,8 +98,10 @@ def _run_cmd_for_serial(ctx, cmd, transports, serial):
                     ctx.fail("Command '{}' is not supported by this device."
                              .format(cmd))
         except FailedOpeningDeviceException:
-            ctx.fail('Failed connecting to a YubiKey with serial: {}'
-                     .format(serial))
+            ctx.fail(
+                'Failed connecting to a YubiKey with serial: {}. \
+                        Make sure the application have the required \
+                            permissions.'.format(serial))
 
 
 def _run_cmd_for_single(ctx, cmd, transports, reader=None):
@@ -127,7 +131,9 @@ def _run_cmd_for_single(ctx, cmd, transports, reader=None):
         try:
             return descriptor.open_device(transports)
         except FailedOpeningDeviceException:
-            ctx.fail('Failed connecting to the YubiKey.')
+            ctx.fail('Failed connecting to {} [{}]. Make sure the application have \
+                    the required permissions.'.format(
+                        descriptor.name, descriptor.mode))
     else:
         _disabled_transport(ctx, transports, cmd)
 
@@ -201,44 +207,58 @@ def list_keys(ctx, serials, readers):
     """
     List connected YubiKeys.
     """
+
+    def _print_device(dev, serial):
+        if serials:
+            if serial:
+                click.echo(serial)
+        else:
+            click.echo('{} [{}]{}'.format(
+                dev.device_name,
+                dev.mode,
+                ' Serial: {}'.format(serial) if serial else '')
+            )
+
     if readers:
         for reader in list_readers():
             click.echo(reader.name)
         ctx.exit()
 
-    all_descriptors = get_descriptors()
-    descriptors = [d for d in all_descriptors if d.key_type != YUBIKEY.SKY]
-    skys = len(all_descriptors) - len(descriptors)
+    descriptors = get_descriptors()
     handled_serials = set()
-    for dev in list_devices():
-        handled = False
-        if skys > 0 and dev.key_type == YUBIKEY.SKY:
-            skys -= 1
-            serial = None
-            handled = True
-        else:
-            serial = dev.serial
-            if serial not in handled_serials:
-                handled_serials.add(serial)
-                matches = [d for d in descriptors if (d.key_type, d.mode)
-                           == (dev.driver.key_type, dev.driver.mode)]
-                if len(matches) > 0:
-                    d = matches[0]
-                    descriptors.remove(d)
-                    handled = True
-        if handled:
-            if serials:
-                if serial:
-                    click.echo(serial)
+
+    try:
+        for dev in list_devices(transports=TRANSPORT.CCID):
+            if dev.key_type == YUBIKEY.SKY:
+                # We have nothing to match on, so just drop a SKY descriptor
+                d = next(x for x in descriptors if x.key_type == YUBIKEY.SKY)
+                descriptors.remove(d)
+                _print_device(dev, None)
             else:
-                click.echo('{} [{}]{}'.format(
-                    dev.device_name,
-                    dev.mode,
-                    ' Serial: {}'.format(serial) if serial else '')
-                )
-        dev.close()
-        if not descriptors and not skys:
-            break
+                serial = dev.serial
+                if serial not in handled_serials:
+                    # Drop a descriptor with a matching serial and mode
+                    handled_serials.add(serial)
+                    matches = [d for d in descriptors if (d.key_type, d.mode)
+                               == (dev.driver.key_type, dev.driver.mode)]
+                    if len(matches) > 0:
+                        d = matches[0]
+                        descriptors.remove(d)
+                        _print_device(dev, serial)
+            dev.close()
+            if not descriptors:
+                break
+    except smartcard.pcsc.PCSCExceptions.EstablishContextException as e:
+        logger.error('Failed to list devices', exc_info=e)
+        ctx.fail(
+            'Failed to establish CCID context. Is the pcscd service running?')
+
+    # List descriptors that failed to open.
+    if len(descriptors) > 0:
+        logger.debug(
+            'Failed to open some devices, listing based on descriptors')
+    for desc in descriptors:
+        click.echo('{} [{}]'.format(desc.name, desc.mode))
 
 
 COMMANDS = (list_keys, info, mode, otp, openpgp, oath, piv, fido, config)
